# Date Picker

People have too many ideas on how to set the time.

## Demos

```demo
date
datetime
daterange
datetimerange
size
disabled
disabled-time
actions
shortcuts
events
format
footerslot
update-on-close
```

## Props

### General Props

| Name | Type | Default | Description |
| --- | --- | --- | --- |
| clearable | `boolean` | `false` | Whether the date picker is clearable. |
| default-value | `number \| [number, number] \| null` | `null` | Date picker's default value. |
| disabled | `boolean` | `false` | Whether the date picker is disabled. |
| shortcuts | `Record<string, number \| [number, number]>` | `undefined` | Shortcut button customizations. |
| size | `'small' \| 'medium' \| 'large'` | `'medium'` | Date picker size. |
| type | `'date' \| 'datetime' \| 'daterange' \|'datetimerange'` | `'date'` | Date picker type. |
| value | `number \| [number, number] \| null` | `undefined` | Value of the date picker when being manually set. |
| on-blur | `() => void` | `undefined` | On blur callback. |
| on-focus | `() => void` | `undefined` | On focus callback. |

### Date Type Props

| Name | Type | Default | Description |
| --- | --- | --- | --- |
| actions | `Array<'clear' \| 'now' \| 'confirm'> \| null` | `['clear', 'now', 'confirm']` | Operations supported for the `date` type date picker. |
| format | `string` | `'yyyy-MM-dd'` | Format of the input. |
| is-date-disabled | `(current: number) => boolean` | `() => false` | Validator of the date. |
| placeholder | `string` | `'Select Date'` | Placeholder. |
| on-update:value | `(value: number \| null) => void` | `undefined` | Date selected callback. |

### DateTime Type Props

| Name | Type | Default | Description |
| --- | --- | --- | --- |
| actions | `Array<'clear' \| 'now' \| 'confirm'> \| null` | `['clear', 'now', 'confirm']` | Operations supported for the `datetime` type date picker. |
| format | `string` | `'yyyy-MM-dd HH:mm:ss'` | Format of the input. |
| is-date-disabled | `(current: number) => boolean` | `() => false` | Validator of the date. |
| is-time-disabled | `(current: number) => { isHourDisabled?: () => boolean, isMinuteDisabled?: () => boolean, isSecondDisabled?: () => boolean }` | `undefined` | Validator of the time. |
| placeholder | `string` | `'Select Date and Time'` | Placeholder. |
| update-value-on-close | `boolean` | `false` | Whether to update value on close. |
| on-update:value | `(value: number \| null) => void` | `undefined` | Date selected callback. |

### DateRange Type Props

| Name | Type | Default | Description |
| --- | --- | --- | --- |
| actions | `Array<'clear' \| 'confirm'> \| null` | `['clear', 'confirm']` | Operations supported for the `daterange` type date picker. |
| end-placeholder | `string` | `'End Date'` | Placeholder at the end of the input. |
| format | `string` | `'yyyy-MM-dd'` | Format of the input. |
| is-date-disabled | `(current: number, phase: 'start' \| 'end', value: [number, number] \| null) => boolean` | `undefined` | Validator of the date. |
| is-time-disabled | `(current: number, phase: 'start' \| 'end', value: [number, number] \| null) => { isHourDisabled?: () => boolean, isMinuteDisabled?: () => boolean, isSecondDisabled?: () => boolean }` | `undefined` | Validator of the time. |
| close-on-select | `boolean` | `false` | Whether to close the panel after the user has selected a time range. |
| separator | `string` | `'to'` | The separator between the start input and the end input. |
| start-placeholder | `string` | `'Start Date'` | The prompt information at the beginning of the input. |
| update-value-on-close | `boolean` | `false` | Whether to update the value on close. |
| on-update:value | `(value: [number, number] \| null) => void` | `undefined` | Range changed callback. |

### DateTimeRange Type Props

| Name | Type | Default | Description |
| --- | --- | --- | --- |
| actions | `Array<'clear' \| 'confirm'> \| null` | `['clear', 'confirm']` | Operations supported for the `datetimerange` type. |
| end-placeholder | `string` | `'End Date and Time'` | Placeholder at the end of the input. |
| format | `string` | `'yyyy-MM-dd HH:mm:ss'` | Format of the input. |
| is-date-disabled | `(current: number, phase: 'start' \| 'end', value: [number, number] \| null) => boolean` | `undefined` | Validator of the date. |
| is-time-disabled | `(current: number, phase: 'start' \| 'end', value: [number, number]) => { isHourDisabled?: () => boolean, isMinuteDisabled?: () => boolean, isSecondDisabled?: () => boolean }` | `undefined` | Validator of the time. |
| separator | `string` | `'to'` | The separator between the start input and the end input. |
| start-placeholder | `string` | `'Start Date and Time'` | The prompt information at the beginning of the input. |
| update-value-on-close | `boolean` | `false` | Whether to update value on close. |
| on-update:value | `(value: [number, number] \| null) => void` | `undefined` | Value changed callback. |

## Slots

| Name   | Parameters | Description          |
| ------ | ---- | ------------- |
| footer | `()` | Extra Footer. |
